@@ -17,6 +17,7 @@ DEFAULT_REDIS_CLIENT = None
 DEFAULT_DJANGO_PROFILE_MODEL = None
 DEFAULT_DJANGO_COUNT_FUNC = None
 DEFAULT_DJANGO_POINTER_MODEL = None
+DEFAULT_DJANGO_CONNECTION_TUPLE = (None, None)
 DEFAULT_PROFILE_TTL = 12 * 60 * 60
 DEFAULT_PROFILE_TTL_MARGIN = 2 * 60 * 60
 DEFAULT_USER_TTL = 6 * 24 * 60 * 60
@@ -49,6 +50,7 @@ class Profile(object):
     redis_client = DEFAULT_REDIS_CLIENT
     django_profile_model = DEFAULT_DJANGO_PROFILE_MODEL
     django_pointer_model = DEFAULT_DJANGO_POINTER_MODEL
+    django_connection_tuple = DEFAULT_DJANGO_CONNECTION_TUPLE
     django_count_func = DEFAULT_DJANGO_COUNT_FUNC
     profile_ttl = DEFAULT_PROFILE_TTL
     profile_ttl_margin = DEFAULT_PROFILE_TTL_MARGIN
@@ -90,6 +92,16 @@ class Profile(object):
             self.build_properties(updated=props_updated,
                                   created=props_created)
 
+    @classmethod
+    def usable_django_model(cls):
+        if cls.django_profile_model:
+            if all(cls.django_connection_tuple):
+                if cls.django_connection_tuple[0] and not cls.django_connection_tuple[0].is_usable():
+                    del cls.django_connection_tuple[1]._connections.default
+                return cls.django_profile_model
+            else:
+                return cls.django_profile_model
+
     def build_properties(self,
                          updated=None,
                          created=None):
@@ -229,7 +241,7 @@ class Profile(object):
     def from_database_by_user_id(cls,
                                  user_id):
 
-        profile_models = cls.django_profile_model.objects.filter(user_id=user_id)
+        profile_models = cls.usable_django_model().objects.filter(user_id=user_id)
         data = {profile_model.profile_id: cls.from_flat_data(data=json.loads(profile_model.data),
                                                              user_id=user_id)
                 for profile_model in profile_models}
@@ -262,7 +274,7 @@ class Profile(object):
 
         for i in range(max_tries):
             try:
-                self.django_profile_model.objects.update_or_create(
+                self.usable_django_model().objects.update_or_create(
                     profile_id=self.profile_id_from_key(self.key),
                     user_id=self.user_id,
                     defaults={'data': datastring})
@@ -276,7 +288,7 @@ class Profile(object):
     def delete_in_db(self):
 
         try:
-            self.django_profile_model.objects.get(profile_id=self.profile_id).delete()
+            self.usable_django_model().objects.get(profile_id=self.profile_id).delete()
         except self.django_profile_model.DoesNotExist:
             pass
 
@@ -447,7 +459,7 @@ class Profile(object):
                                   user_ids):
 
         user_ids = [u for u in user_ids if not cls.db_lookup_failed_before(u)]
-        profile_models = cls.django_profile_model.objects.filter(user_id__in=user_ids)
+        profile_models = cls.usable_django_model().objects.filter(user_id__in=user_ids)
 
         result = {}
 
@@ -469,7 +481,7 @@ class Profile(object):
                       key,
                       user_id):
         try:
-            profile_model = cls.django_profile_model.objects.get(profile_id=cls.profile_id_from_key(key),
+            profile_model = cls.usable_django_model().objects.get(profile_id=cls.profile_id_from_key(key),
                                                              user_id=user_id)
         except cls.django_profile_model.DoesNotExist:
             return None
@@ -660,7 +672,7 @@ class Profile(object):
                                             num,
                                             start):
 
-        result = cls.django_profile_model.objects.all().values('user_id').annotate(
+        result = cls.usable_django_model().objects.all().values('user_id').annotate(
             count=cls.django_count_func('user_id')).filter(count__gt=1).order_by()[start:start + num]
         return [str(res['user_id']) for res in result]
 
@@ -672,7 +684,7 @@ class Profile(object):
         keys = [key.decode() if isinstance(key, bytes) else key for key in keys]
         profile_ids = [cls.profile_id_from_key(key) for key in keys]
 
-        profile_models = list(cls.django_profile_model.objects.filter(profile_id__in=profile_ids, user_id=user_id))
+        profile_models = list(cls.usable_django_model().objects.filter(profile_id__in=profile_ids, user_id=user_id))
         profiles = {cls._profile_key(profile_model.profile_id):
                         cls.from_flat_data(data=json.loads(profile_model.data),
                                            user_id=user_id)
